@@ -65,6 +65,7 @@
 #include "ausearch.h"
 #include "useradd.h"
 #include "seeprocess.h"
+#include "restorecon.h"
 #include "mainwindow.h"
 
 MainWindow::MainWindow(QWidget *parent, const char *name)
@@ -110,6 +111,7 @@ MainWindow::MainWindow(QWidget *parent, const char *name)
 	ausearch_o = 0;
 	useradd_o = 0;
 	seeprocess_o = 0;
+	restorecon_o = 0;
 
 	//connect SIGNAL to objects    
 
@@ -125,7 +127,7 @@ MainWindow::MainWindow(QWidget *parent, const char *name)
 	createToolBars();
 	createStatusBar();
 
-	setCaption(tr("segatex-6.10"));
+	setCaption(tr("segatex-6.20"));
 	setIcon(QPixmap::fromMimeSource("icon.png"));
 }
 
@@ -484,6 +486,11 @@ void MainWindow::createActions()
 	seeprocessAct->setStatusTip(tr("see process"));
 	connect(seeprocessAct, SIGNAL(activated()), this, SLOT(seeprocess()));
 	connect(seeprocessAct, SIGNAL(activated()), this, SLOT(updateSegatexStateIndicator()));
+
+	restoreconAct = new QAction(tr("&restorecon"), 0, this);
+	restoreconAct->setStatusTip(tr("restorecon"));
+	connect(restoreconAct, SIGNAL(activated()), this, SLOT(restorecon()));
+	connect(restoreconAct, SIGNAL(activated()), this, SLOT(updateSegatexStateIndicator()));
 }
 
 void MainWindow::createMenus()
@@ -569,6 +576,7 @@ void MainWindow::createMenus()
 	semanage_core_boolean_processAct->addTo(semanageMenu);
 
 	autorelabelMenu = new QPopupMenu(this);
+	restoreconAct->addTo(autorelabelMenu);
 	autorelabel_processAct->addTo(autorelabelMenu);
 
 	miscellaneousMenu = new QPopupMenu(this);
@@ -932,7 +940,7 @@ void MainWindow::notice()
 void MainWindow::about()
 {
 	QMessageBox::about(this, tr("About segatex"),
-		tr("<h2>segatex-6.10</h2>"
+		tr("<h2>segatex-6.20</h2>"
 		"<p>Copyright &copy; 2007-2008"
 		"<p>Shintaro Fujiwara."
 		"<p>segatex is a SELinux tool"
@@ -958,6 +966,7 @@ void MainWindow::howtouse()
 		" Analize audit.log-generate policy."
 		" You can aureport."
 		" You can ausearch."
+		" You can restorecon."
 		"<p><font color=\"blue\">[segatex_editor]</font>"
 		"<p>Push Parselines,Selpaw,Refine"
 		" one by one orderly."
@@ -1229,3 +1238,12 @@ void MainWindow::seeprocess()
 	seeprocess_o->raise();
 	seeprocess_o->setActiveWindow();
 }
+void MainWindow::restorecon()
+{
+	if(!restorecon_o) {
+		restorecon_o = new Restorecon(this);
+	}
+	restorecon_o->show();
+	restorecon_o->raise();
+	restorecon_o->setActiveWindow();
+}
