@@ -62,6 +62,7 @@ class Aureport;
 class Ausearch;
 class Useradd;
 class Seeprocess;
+class Restorecon;
 
 class MainWindow : public QMainWindow
 {
@@ -122,6 +123,7 @@ private slots:
     void ausearch();
     void useradd();
     void seeprocess();
+    void restorecon();
 
     void save();
     void saveAs();
@@ -196,6 +198,7 @@ private:
     Ausearch *ausearch_o;
     Useradd *useradd_o;
     Seeprocess *seeprocess_o;
+    Restorecon *restorecon_o;
     
     QPopupMenu *fileMenu;
     QPopupMenu *editMenu;
@@ -275,6 +278,7 @@ private:
     QAction *ausearchAct;
     QAction *useraddAct;
     QAction *seeprocessAct;
+    QAction *restoreconAct;
 };
 
 #endif
