@@ -1,7 +1,7 @@
 /*
  * segatex SELinux tool.
  *
- * Copyright (C) 2007 Shintaro Fujiwara 
+ * Copyright (C) 2007-2008 Shintaro Fujiwara 
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -41,7 +41,7 @@ SemanageCorePortProcess::SemanageCorePortProcess(QWidget *parent, const char *na
 {
 	setCaption(tr("Semanage Port Process"));
 	textEdit1 = new QTextEdit(this);
-	textEdit1->setPaletteBackgroundColor(QColor(0,254,100));
+	textEdit1->setPaletteBackgroundColor(QColor(250,180,200));
 
 	semanageEditLabel = new QLabel(tr("Add port(port_type):"), this );
 	semanageEditLineEdit = new QLineEdit( this );
@@ -56,7 +56,7 @@ SemanageCorePortProcess::SemanageCorePortProcess(QWidget *parent, const char *na
 	semanageEditLineEdit6->setText("");
 	semanageEditLineEdit6->setPaletteBackgroundColor(QColor(255,100,200));
 	addButton = new QPushButton(tr("Add port"), this);
-	addButton->setPaletteBackgroundColor(QColor(20,157,100));
+	addButton->setPaletteBackgroundColor(QColor(200,157,100));
 	connect(addButton, SIGNAL(clicked()), this, SLOT(add_button_clicked()));
 
 	semanageEditLabel3 = new QLabel(tr("Delete port(port_type):"), this );
@@ -72,7 +72,7 @@ SemanageCorePortProcess::SemanageCorePortProcess(QWidget *parent, const char *na
 	semanageEditLineEdit8->setText("");
 	semanageEditLineEdit8->setPaletteBackgroundColor(QColor(255,100,200));
 	deleteButton = new QPushButton(tr("Delete port"), this);
-	deleteButton->setPaletteBackgroundColor(QColor(20,157,100));
+	deleteButton->setPaletteBackgroundColor(QColor(200,157,100));
 	connect(deleteButton, SIGNAL(clicked()), this, SLOT(delete_button_clicked()));
 
 	semanageEditLabel4 = new QLabel(tr("Modify port(port_type):"), this );
@@ -88,7 +88,7 @@ SemanageCorePortProcess::SemanageCorePortProcess(QWidget *parent, const char *na
 	semanageEditLineEdit9->setText("");
 	semanageEditLineEdit9->setPaletteBackgroundColor(QColor(255,100,200));
 	modifyButton = new QPushButton(tr("Modify port"), this);
-	modifyButton->setPaletteBackgroundColor(QColor(20,157,100));
+	modifyButton->setPaletteBackgroundColor(QColor(200,157,100));
 	connect(modifyButton, SIGNAL(clicked()), this, SLOT(modify_button_clicked()));
 
 	closeButton = new QPushButton(tr("close"), this);
@@ -320,14 +320,6 @@ void SemanageCorePortProcess::readFromOutputFile()
 			name = *it_d;
 			file_interface_name = dir_name + forward_slash + name;
 			QFile file( file_interface_name );
-			/*
-			QRegExp rx_nologin("nologin");
-			QRegExp rx_shutdown("shutdown");
-			QRegExp rx_halt("halt");
-			QRegExp rx_news("news");
-			QRegExp rx_false("false");
-			QRegExp rx_sync("sync");
-			*/
 			if ( file.open( IO_ReadOnly ) ) {
 				QTextStream stream( &file );
 				////////////////////////////////////////////
@@ -335,32 +327,11 @@ void SemanageCorePortProcess::readFromOutputFile()
 				if(order_x == 1)
 					textEdit1->append("#########port list#########");
 					textEdit1->append("");
-				/*
-				if(order_x == 2)
-					textEdit1->append("#########user list#########");
-					textEdit1->append("");
-				if(order_x == 3)
-					textEdit1->append("#########etc passwd list#########");
-					textEdit1->append("");
-				*/
 				while ( !stream.atEnd() ) {
 					line_analized = stream.readLine(); // line of text excluding '\n'
-					//buttons.push_back(line_analized);
-					/*
-					i = line_analized.find( rx_nologin, 0);
-					j = line_analized.find( rx_shutdown, 0);
-					k = line_analized.find( rx_halt, 0);
-					l = line_analized.find( rx_news, 0);
-					m = line_analized.find( rx_false, 0);
-					n = line_analized.find( rx_sync, 0);
-					*/
-                                        //if((i != -1)||(j != -1)||(k != -1)||(l != -1)||(m != -1)||(n != -1)){
-						//do nothing
-					//}else{
-						textEdit1->append(line_analized);
-					//}
+					textEdit1->append(line_analized);
 				}
-				//file.close();
+				textEdit1->setCursorPosition(0,0);
 				order_x++;
 				++it_d;
 			}else{
